// -*- C++ -*-
//
//  This file is part of Siena, a wide-area event notification system.
//  See http://www.cs.colorado.edu/serl/siena/
//
//  Author: Antonio Carzaniga <carzanig@cs.colorado.edu>
//  See the file AUTHORS for full details. 
//
//  Copyright (C) 1998-2002 University of Colorado
//
//  This program is free software; you can redistribute it and/or
//  modify it under the terms of the GNU General Public License
//  as published by the Free Software Foundation; either version 2
//  of the License, or (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307,
//  USA, or send email to serl@cs.colorado.edu.
//
//
// $Id: Db.cc,v 1.4 2002/11/22 20:57:45 carzanig Exp $
//
#include <gdbm.h>
#include <fcntl.h>
#include <string>

using namespace std;

#include "Db.h"

const char * DbError::what() const throw() {
    return "couldn't open repository";
};

Db::Db(const char *filename)
{
    db = gdbm_open((char *)filename, 0, O_RDWR | O_CREAT, 0600, 
		   (void (*)())0);
    if (db == NULL) { 
	throw DbError();
    }
}

Db::~Db() 
{
    if (db != NULL) gdbm_close(db);
}

Datum	Db::firstkey()
{
    return gdbm_firstkey(db);
}

Datum	Db::nextkey(Datum key)
{
    if (key.is_null()) return key;
    return gdbm_nextkey(db, *key.rep);
}

Datum Db::get(Datum key)
{
    if (key.is_null()) return key;
    return gdbm_fetch(db, *key.rep);
}

int Db::erase(Datum key)
{
    if (key.is_null()) return -1;
    return gdbm_delete(db, *key.rep);
}

int Db::set(Datum key, Datum value)
{
    if (key.is_null() || value.is_null()) return -1;
    return gdbm_store(db, *key.rep, *value.rep, GDBM_REPLACE);
}
