// -*- C++ -*-
//
//  This file is part of Siena, a wide-area event notification system.
//  See http://www.cs.colorado.edu/serl/siena/
//
//  Author: Antonio Carzaniga <carzanig@cs.colorado.edu>
//  See the file AUTHORS for full details. 
//
//  Copyright (C) 1998-2002 University of Colorado
//
//  This program is free software; you can redistribute it and/or
//  modify it under the terms of the GNU General Public License
//  as published by the Free Software Foundation; either version 2
//  of the License, or (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307,
//  USA, or send email to serl@cs.colorado.edu.
//
//
// $Id: Db.h,v 1.3 2002/11/22 20:57:45 carzanig Exp $
//
#ifndef _Db_h
#define _Db_h

#include <cstdlib>
#include <gdbm.h>
#include <string>
#include <exception>

using namespace std;

class Datum;
class Db;
class DbError;

class DatumRep: public datum {
private:
    bool do_free;
    unsigned int refcount;
    friend class Datum;
    ~DatumRep() { if (do_free && dptr != NULL) free(dptr); }
};

class Datum {
private:
    DatumRep *rep;
    friend class Db;
public:
    Datum(): rep(NULL) {};
    Datum(const Datum &i): rep(i.rep) {
	if (rep != NULL) rep->refcount++;
    }

    Datum(const datum & d) {
	if (d.dptr == NULL) {
	    rep = NULL;
	} else {
	    rep = new DatumRep();
	    rep->do_free = true;
	    rep->dptr = d.dptr;
	    rep->dsize = d.dsize;
	    rep->refcount = 1;
	}
    };
    Datum(const string & s) {
	rep = new DatumRep();
	rep->do_free = false;
	rep->refcount = 1;
	rep->dptr = (char*)s.c_str();
	rep->dsize = s.size();
    };

    Datum(char * c, size_t s) {
	rep = new DatumRep();
	rep->do_free = false;
	rep->refcount = 1;
	rep->dptr = c;
	rep->dsize = s;
    };

    Datum & operator = (const Datum &i) {
	if (rep == i.rep) return *this;
	if (rep != NULL && --rep->refcount == 0) delete(rep);
	rep = i.rep;
	if (rep != NULL) rep->refcount++;
	return *this;
    }

    Datum & operator = (const string & s) {
	if (rep != NULL && --rep->refcount == 0) delete(rep);
	rep = new DatumRep();
	rep->do_free = false;
	rep->refcount = 1;
	rep->dptr = (char*)s.c_str();
	rep->dsize = s.size();
	return *this;
    };

    Datum & operator = (const datum & d) {
	if (rep != NULL && --rep->refcount == 0) delete(rep);
	if (d.dptr == NULL) {
	    rep = NULL;
	} else {
	    rep = new DatumRep();
	    rep->do_free = false;
	    rep->dptr = d.dptr;
	    rep->dsize = d.dsize;
	    rep->refcount = 1;
	}
	return *this;
    };

    bool is_null() const { return rep == NULL || rep->dptr == NULL; };

    const char *ptr() const { return (rep == NULL) ? NULL : rep->dptr; };
    size_t size() const { return (rep == NULL) ? 0 : rep->dsize; };

    string to_string() { return string(rep->dptr, rep->dsize); }
};

class Db {
 public:
		Db(const char *);
		~Db();

    Datum	firstkey();
    Datum	nextkey(Datum);
    Datum	get(Datum key);
    int		set(Datum key, Datum value);
    int		erase(Datum key);

 private:
    GDBM_FILE	db;
};

class DbError : public exception {
    virtual const char * what() const throw();
};

#endif /* _Db_h */
