#!/bin/sh
#
#  This file is part of Siena, a wide-area event notification system.
#  See http://www.cs.colorado.edu/serl/dot/siena.html
#
#  Author: Antonio Carzaniga <carzanig@cs.colorado.edu>
#  See the file AUTHORS for full details. 
#
#  Copyright (C) 1998-1999 University of Colorado
#
#  This program is free software; you can redistribute it and/or
#  modify it under the terms of the GNU General Public License
#  as published by the Free Software Foundation; either version 2
#  of the License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software
#  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307,
#  USA, or send email to serl@cs.colorado.edu.
#
#
# $Id: test_float.sh,v 1.1 2002/06/10 20:19:15 carzanig Exp $
#
. ./config
. $srcdir/base.sh
#
cat<<EOF
Tested Feature:		float filters

Topology:		1 server, 1 object, 1 party
Interface functions:	subscribe, unsubscribe, publish
Notification classes:	single attribute
             types:	string, integer, boolean, float
Filter classes:		single attribute, single constraint
       types:		float
       operators:	= != > < >= <=
EOF
#
pause=
#
# opentest <topology> [notopology | restart]
#
opentest 1 $*
#
# --------------- TEST BEGINS HERE -----------------
#

#
# in this first section, I use float literals as integers:
#

#
# @0 1 <-- {x=321.0}
#
incref
send<<EOF
senp{to="$siena0" method="SUB" ref=$ref subscriber="$client/1"}
filter{x=321.0}
EOF
#
#
incref
send<<EOF
senp{to="$siena0" method="PUB" ref=$ref}
event{x=321}
EOF
expect<<EOF
senp{from="$siena0" method="PUB" ref=$ref to="$client/1" }
event{x=321}
EOF
#
#
incref
send<<EOF
senp{to="$siena0" method="PUB" ref=$ref}
event{x=321.0}
EOF
expect<<EOF
senp{from="$siena0" method="PUB" ref=$ref to="$client/1" }
event{x=321.0}
EOF
#
#
incref
send<<EOF
senp{to="$siena0" method="PUB" ref=$ref}
event{x=3210}
EOF
#
#
incref
send<<EOF
senp{to="$siena0" method="PUB" ref=$ref}
event{x=-321}
EOF
#
#
#
incref
send<<EOF
senp{to="$siena0" method="PUB" ref=$ref}
event{x="321"}
EOF
#
#
incref
send<<EOF
senp{to="$siena0" method="PUB" ref=$ref}
event{x=false}
EOF
#
#
incref
send<<EOF
senp{to="$siena0" method="PUB" ref=$ref}
event{x=0.321}
EOF
#
#
incref
send<<EOF
senp{to="$siena0" method="UNS" ref=$ref subscriber="$client/1"}
filter{x=321.0}
EOF
#
# @0 1 <-- {x != 321.0}
#
incref
send<<EOF
senp{to="$siena0" method="SUB" ref=$ref subscriber="$client/1"}
filter{x != 321.0}
EOF
#
#
incref
send<<EOF
senp{to="$siena0" method="PUB" ref=$ref}
event{x=321}
EOF
#
#
incref
send<<EOF
senp{to="$siena0" method="PUB" ref=$ref}
event{x=321.0}
EOF
#
#
incref
send<<EOF
senp{to="$siena0" method="PUB" ref=$ref}
event{x=3210}
EOF
expect<<EOF
senp{from="$siena0" method="PUB" ref=$ref to="$client/1" }
event{x=3210}
EOF
#
#
incref
send<<EOF
senp{to="$siena0" method="PUB" ref=$ref}
event{x=-321}
EOF
expect<<EOF
senp{from="$siena0" method="PUB" ref=$ref to="$client/1" }
event{x=-321}
EOF
#
#
incref
send<<EOF
senp{to="$siena0" method="PUB" ref=$ref}
event{x="321"}
EOF
expect<<EOF
senp{from="$siena0" method="PUB" ref=$ref to="$client/1" }
event{x="321"}
EOF
#
#
incref
send<<EOF
senp{to="$siena0" method="PUB" ref=$ref}
event{x=false}
EOF
expect<<EOF
senp{from="$siena0" method="PUB" ref=$ref to="$client/1" }
event{x=false}
EOF
#
#
incref
send<<EOF
senp{to="$siena0" method="PUB" ref=$ref}
event{x=0.321}
EOF
expect<<EOF
senp{from="$siena0" method="PUB" ref=$ref to="$client/1" }
event{x=0.321}
EOF
#
incref
send<<EOF
senp{to="$siena0" method="UNS" ref=$ref subscriber="$client/1"}
filter{x != 321.0}
EOF
#
# @0 1 <-- {x > 321.0}
#
incref
send<<EOF
senp{to="$siena0" method="SUB" ref=$ref subscriber="$client/1"}
filter{x > 321.0}
EOF
#
#
incref
send<<EOF
senp{to="$siena0" method="PUB" ref=$ref}
event{x=322}
EOF
expect<<EOF
senp{from="$siena0" method="PUB" ref=$ref to="$client/1" }
event{x=322}
EOF
#
#
incref
send<<EOF
senp{to="$siena0" method="PUB" ref=$ref}
event{x=1234.12}
EOF
expect<<EOF
senp{from="$siena0" method="PUB" ref=$ref to="$client/1" }
event{x=1234.12}
EOF
#
#
incref
send<<EOF
senp{to="$siena0" method="PUB" ref=$ref}
event{x=321}
EOF
#
#
incref
send<<EOF
senp{to="$siena0" method="PUB" ref=$ref}
event{x=-500}
EOF
#
#
#
incref
send<<EOF
senp{to="$siena0" method="PUB" ref=$ref}
event{x="400"}
EOF
#
#
incref
send<<EOF
senp{to="$siena0" method="PUB" ref=$ref}
event{x=false}
EOF
#
#
incref
send<<EOF
senp{to="$siena0" method="PUB" ref=$ref}
event{x=0.321}
EOF
#
#
incref
send<<EOF
senp{to="$siena0" method="UNS" ref=$ref subscriber="$client/1"}
filter{x > 321.0}
EOF
#
# @0 1 <-- {x < 321.0}
#
incref
send<<EOF
senp{to="$siena0" method="SUB" ref=$ref subscriber="$client/1"}
filter{x < 321.0}
EOF
#
#
incref
send<<EOF
senp{to="$siena0" method="PUB" ref=$ref}
event{x=320}
EOF
expect<<EOF
senp{from="$siena0" method="PUB" ref=$ref to="$client/1" }
event{x=320}
EOF
#
#
incref
send<<EOF
senp{to="$siena0" method="PUB" ref=$ref}
event{x=123.12}
EOF
expect<<EOF
senp{from="$siena0" method="PUB" ref=$ref to="$client/1" }
event{x=123.12}
EOF
#
#
incref
send<<EOF
senp{to="$siena0" method="PUB" ref=$ref}
event{x=321}
EOF
#
#
incref
send<<EOF
senp{to="$siena0" method="PUB" ref=$ref}
event{x=-234}
EOF
expect<<EOF
senp{from="$siena0" method="PUB" ref=$ref to="$client/1" }
event{x=-234}
EOF
#
#
incref
send<<EOF
senp{to="$siena0" method="PUB" ref=$ref}
event{x="1"}
EOF
#
#
incref
send<<EOF
senp{to="$siena0" method="PUB" ref=$ref}
event{x=false}
EOF
#
#
incref
send<<EOF
senp{to="$siena0" method="PUB" ref=$ref}
event{x=1234.321}
EOF
#
#
incref
send<<EOF
senp{to="$siena0" method="UNS" ref=$ref subscriber="$client/1"}
filter{x < 321.0}
EOF
#
# @0 1 <-- {x <= 321.0}
#
incref
send<<EOF
senp{to="$siena0" method="SUB" ref=$ref subscriber="$client/1"}
filter{x <= 321.0}
EOF
#
#
incref
send<<EOF
senp{to="$siena0" method="PUB" ref=$ref}
event{x=321}
EOF
expect<<EOF
senp{from="$siena0" method="PUB" ref=$ref to="$client/1" }
event{x=321}
EOF
#
#
incref
send<<EOF
senp{to="$siena0" method="PUB" ref=$ref}
event{x=123.12}
EOF
expect<<EOF
senp{from="$siena0" method="PUB" ref=$ref to="$client/1" }
event{x=123.12}
EOF
#
#
incref
send<<EOF
senp{to="$siena0" method="PUB" ref=$ref}
event{x=322}
EOF
#
#
incref
send<<EOF
senp{to="$siena0" method="PUB" ref=$ref}
event{x=-234}
EOF
expect<<EOF
senp{from="$siena0" method="PUB" ref=$ref to="$client/1" }
event{x=-234}
EOF
#
#
incref
send<<EOF
senp{to="$siena0" method="PUB" ref=$ref}
event{x="1"}
EOF
#
#
incref
send<<EOF
senp{to="$siena0" method="PUB" ref=$ref}
event{x=false}
EOF
#
#
incref
send<<EOF
senp{to="$siena0" method="PUB" ref=$ref}
event{x=1234.321}
EOF
#
#
incref
send<<EOF
senp{to="$siena0" method="UNS" ref=$ref subscriber="$client/1"}
filter{x <= 321.0}
EOF
#
# @0 1 <-- {x >= 321}
#
incref
send<<EOF
senp{to="$siena0" method="SUB" ref=$ref subscriber="$client/1"}
filter{x >= 321.0}
EOF
#
#
incref
send<<EOF
senp{to="$siena0" method="PUB" ref=$ref}
event{x=321}
EOF
expect<<EOF
senp{from="$siena0" method="PUB" ref=$ref to="$client/1" }
event{x=321}
EOF
#
#
incref
send<<EOF
senp{to="$siena0" method="PUB" ref=$ref}
event{x=1234.12}
EOF
expect<<EOF
senp{from="$siena0" method="PUB" ref=$ref to="$client/1" }
event{x=1234.12}
EOF
#
#
incref
send<<EOF
senp{to="$siena0" method="PUB" ref=$ref}
event{x=320}
EOF
#
#
incref
send<<EOF
senp{to="$siena0" method="PUB" ref=$ref}
event{x=-500}
EOF
#
#
#
incref
send<<EOF
senp{to="$siena0" method="PUB" ref=$ref}
event{x="400"}
EOF
#
#
incref
send<<EOF
senp{to="$siena0" method="PUB" ref=$ref}
event{x=false}
EOF
#
#
incref
send<<EOF
senp{to="$siena0" method="PUB" ref=$ref}
event{x=0.321}
EOF
#
#
incref
send<<EOF
senp{to="$siena0" method="UNS" ref=$ref subscriber="$client/1"}
filter{x >= 321.0}
EOF
#

#
# second section: actual float values
#

#
# @0 1 <-- {x=321}
#
incref
send<<EOF
senp{to="$siena0" method="SUB" ref=$ref subscriber="$client/1"}
filter{x=321.5}
EOF
#
#
incref
send<<EOF
senp{to="$siena0" method="PUB" ref=$ref}
event{x=321}
EOF
#
#
incref
send<<EOF
senp{to="$siena0" method="PUB" ref=$ref}
event{x=321.5}
EOF
expect<<EOF
senp{from="$siena0" method="PUB" ref=$ref to="$client/1" }
event{x=321.5}
EOF
#
#
incref
send<<EOF
senp{to="$siena0" method="PUB" ref=$ref}
event{x=3210}
EOF
#
#
incref
send<<EOF
senp{to="$siena0" method="PUB" ref=$ref}
event{x=-321.5}
EOF
#
#
#
incref
send<<EOF
senp{to="$siena0" method="PUB" ref=$ref}
event{x="321.5"}
EOF
#
#
incref
send<<EOF
senp{to="$siena0" method="PUB" ref=$ref}
event{x=false}
EOF
#
#
incref
send<<EOF
senp{to="$siena0" method="PUB" ref=$ref}
event{x=0.321}
EOF
#
#
incref
send<<EOF
senp{to="$siena0" method="UNS" ref=$ref subscriber="$client/1"}
filter{x=321.5}
EOF
#
# @0 1 <-- {x != 321}
#
incref
send<<EOF
senp{to="$siena0" method="SUB" ref=$ref subscriber="$client/1"}
filter{x != 321.5}
EOF
#
#
incref
send<<EOF
senp{to="$siena0" method="PUB" ref=$ref}
event{x=321}
EOF
expect<<EOF
senp{from="$siena0" method="PUB" ref=$ref to="$client/1" }
event{x=321}
EOF
#
#
incref
send<<EOF
senp{to="$siena0" method="PUB" ref=$ref}
event{x=321.5}
EOF
#
#
incref
send<<EOF
senp{to="$siena0" method="PUB" ref=$ref}
event{x=3210}
EOF
expect<<EOF
senp{from="$siena0" method="PUB" ref=$ref to="$client/1" }
event{x=3210}
EOF
#
#
incref
send<<EOF
senp{to="$siena0" method="PUB" ref=$ref}
event{x=-321.5}
EOF
expect<<EOF
senp{from="$siena0" method="PUB" ref=$ref to="$client/1" }
event{x=-321.5}
EOF
#
#
incref
send<<EOF
senp{to="$siena0" method="PUB" ref=$ref}
event{x="321.5"}
EOF
expect<<EOF
senp{from="$siena0" method="PUB" ref=$ref to="$client/1" }
event{x="321.5"}
EOF
#
#
incref
send<<EOF
senp{to="$siena0" method="PUB" ref=$ref}
event{x=false}
EOF
expect<<EOF
senp{from="$siena0" method="PUB" ref=$ref to="$client/1" }
event{x=false}
EOF
#
#
incref
send<<EOF
senp{to="$siena0" method="PUB" ref=$ref}
event{x=0.3215}
EOF
expect<<EOF
senp{from="$siena0" method="PUB" ref=$ref to="$client/1" }
event{x=0.3215}
EOF
#
incref
send<<EOF
senp{to="$siena0" method="UNS" ref=$ref subscriber="$client/1"}
filter{x != 321.5}
EOF
#
# @0 1 <-- {x > 321}
#
incref
send<<EOF
senp{to="$siena0" method="SUB" ref=$ref subscriber="$client/1"}
filter{x > 321.76}
EOF
#
#
incref
send<<EOF
senp{to="$siena0" method="PUB" ref=$ref}
event{x=321.77}
EOF
expect<<EOF
senp{from="$siena0" method="PUB" ref=$ref to="$client/1" }
event{x=321.77}
EOF
#
#
incref
send<<EOF
senp{to="$siena0" method="PUB" ref=$ref}
event{x=1234.12}
EOF
expect<<EOF
senp{from="$siena0" method="PUB" ref=$ref to="$client/1" }
event{x=1234.12}
EOF
#
incref
send<<EOF
senp{to="$siena0" method="PUB" ref=$ref}
event{x=322}
EOF
expect<<EOF
senp{from="$siena0" method="PUB" ref=$ref to="$client/1" }
event{x=322}
EOF
#
#
incref
send<<EOF
senp{to="$siena0" method="PUB" ref=$ref}
event{x=321}
EOF
#
#
incref
send<<EOF
senp{to="$siena0" method="PUB" ref=$ref}
event{x=-500}
EOF
#
#
#
incref
send<<EOF
senp{to="$siena0" method="PUB" ref=$ref}
event{x="400"}
EOF
#
#
incref
send<<EOF
senp{to="$siena0" method="PUB" ref=$ref}
event{x=false}
EOF
#
#
incref
send<<EOF
senp{to="$siena0" method="PUB" ref=$ref}
event{x=0.321}
EOF
#
#
incref
send<<EOF
senp{to="$siena0" method="UNS" ref=$ref subscriber="$client/1"}
filter{x > 321.76}
EOF
#
# @0 1 <-- {x < 321}
#
incref
send<<EOF
senp{to="$siena0" method="SUB" ref=$ref subscriber="$client/1"}
filter{x < 321.21}
EOF
#
#
incref
send<<EOF
senp{to="$siena0" method="PUB" ref=$ref}
event{x=321}
EOF
expect<<EOF
senp{from="$siena0" method="PUB" ref=$ref to="$client/1" }
event{x=321}
EOF
#
#
incref
send<<EOF
senp{to="$siena0" method="PUB" ref=$ref}
event{x=321.20}
EOF
expect<<EOF
senp{from="$siena0" method="PUB" ref=$ref to="$client/1" }
event{x=321.20}
EOF
#
#
incref
send<<EOF
senp{to="$siena0" method="PUB" ref=$ref}
event{x=321.211}
EOF
#
#
incref
send<<EOF
senp{to="$siena0" method="PUB" ref=$ref}
event{x=-234}
EOF
expect<<EOF
senp{from="$siena0" method="PUB" ref=$ref to="$client/1" }
event{x=-234}
EOF
#
#
incref
send<<EOF
senp{to="$siena0" method="PUB" ref=$ref}
event{x="1"}
EOF
#
#
incref
send<<EOF
senp{to="$siena0" method="PUB" ref=$ref}
event{x=false}
EOF
#
#
incref
send<<EOF
senp{to="$siena0" method="PUB" ref=$ref}
event{x=1234.321}
EOF
#
#
incref
send<<EOF
senp{to="$siena0" method="UNS" ref=$ref subscriber="$client/1"}
filter{x < 321.21}
EOF
#
# @0 1 <-- {x <= 321.45}
#
incref
send<<EOF
senp{to="$siena0" method="SUB" ref=$ref subscriber="$client/1"}
filter{x <= 321.45}
EOF
#
#
incref
send<<EOF
senp{to="$siena0" method="PUB" ref=$ref}
event{x=321}
EOF
expect<<EOF
senp{from="$siena0" method="PUB" ref=$ref to="$client/1" }
event{x=321}
EOF
#
#
incref
send<<EOF
senp{to="$siena0" method="PUB" ref=$ref}
event{x=321.45}
EOF
expect<<EOF
senp{from="$siena0" method="PUB" ref=$ref to="$client/1" }
event{x=321.45}
EOF
#
incref
send<<EOF
senp{to="$siena0" method="PUB" ref=$ref}
event{x=321.1}
EOF
expect<<EOF
senp{from="$siena0" method="PUB" ref=$ref to="$client/1" }
event{x=321.1}
EOF
#
#
incref
send<<EOF
senp{to="$siena0" method="PUB" ref=$ref}
event{x=322}
EOF
#
#
incref
send<<EOF
senp{to="$siena0" method="PUB" ref=$ref}
event{x=321.5}
EOF
#
#
incref
send<<EOF
senp{to="$siena0" method="PUB" ref=$ref}
event{x=-234}
EOF
expect<<EOF
senp{from="$siena0" method="PUB" ref=$ref to="$client/1" }
event{x=-234}
EOF
#
#
incref
send<<EOF
senp{to="$siena0" method="PUB" ref=$ref}
event{x="1"}
EOF
#
#
incref
send<<EOF
senp{to="$siena0" method="PUB" ref=$ref}
event{x=false}
EOF
#
#
incref
send<<EOF
senp{to="$siena0" method="PUB" ref=$ref}
event{x=1234.321}
EOF
#
#
incref
send<<EOF
senp{to="$siena0" method="UNS" ref=$ref subscriber="$client/1"}
filter{x <= 321.45}
EOF
#
# @0 1 <-- {x >= 321.01}
#
incref
send<<EOF
senp{to="$siena0" method="SUB" ref=$ref subscriber="$client/1"}
filter{x >= 321.01}
EOF
#
#
incref
send<<EOF
senp{to="$siena0" method="PUB" ref=$ref}
event{x=322}
EOF
expect<<EOF
senp{from="$siena0" method="PUB" ref=$ref to="$client/1" }
event{x=322}
EOF
#
#
incref
send<<EOF
senp{to="$siena0" method="PUB" ref=$ref}
event{x=321.01}
EOF
expect<<EOF
senp{from="$siena0" method="PUB" ref=$ref to="$client/1" }
event{x=321.01}
EOF
#
#
incref
send<<EOF
senp{to="$siena0" method="PUB" ref=$ref}
event{x=321.99}
EOF
expect<<EOF
senp{from="$siena0" method="PUB" ref=$ref to="$client/1" }
event{x=321.99}
EOF
#
#
incref
send<<EOF
senp{to="$siena0" method="PUB" ref=$ref}
event{x=321}
EOF
#
#
incref
send<<EOF
senp{to="$siena0" method="PUB" ref=$ref}
event{x=-500}
EOF
#
#
incref
send<<EOF
senp{to="$siena0" method="PUB" ref=$ref}
event{x="400"}
EOF
#
#
incref
send<<EOF
senp{to="$siena0" method="PUB" ref=$ref}
event{x=false}
EOF
#
#
incref
send<<EOF
senp{to="$siena0" method="PUB" ref=$ref}
event{x=0.321}
EOF
#
#
incref
send<<EOF
senp{to="$siena0" method="UNS" ref=$ref subscriber="$client/1"}
filter{x >= 321.01}
EOF
#
#
# --------------- TEST ENDS HERE -----------------
#
closetest $*
