#!/bin/sh
#
#  This file is part of Siena, a wide-area event notification system.
#  See http://www.cs.colorado.edu/serl/dot/siena.html
#
#  Author: Antonio Carzaniga <carzanig@cs.colorado.edu>
#  See the file AUTHORS for full details. 
#
#  Copyright (C) 1998-1999 University of Colorado
#
#  This program is free software; you can redistribute it and/or
#  modify it under the terms of the GNU General Public License
#  as published by the Free Software Foundation; either version 2
#  of the License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software
#  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307,
#  USA, or send email to serl@cs.colorado.edu.
#
#
# $Id: test_net1.sh,v 1.1 2002/06/10 20:19:15 carzanig Exp $
#
. ./config
. $srcdir/base.sh
#
pause=1
#
cat<<EOF
Feature:		-nets- multiple overlapping subscriptions

Topology:		3 servers, multiple objects, multiple parties
Interface functions:	subscribe, unsubscribe, publish
Notification classes:	multiple attributes
Attribute types:	string, integer
Filter classes:		multiple attribute, multiple constraint
Filter operators:	> = any
EOF
#
# server topology setup
#
opentest 3 $*
#
# -------------------- TEST BEGINS HERE --------------------
#
# @0 1 <-- {x any}
#
incref
send <<EOF
senp{ to="$siena0" method="SUB" ref=$ref subscriber="$client/1"}
filter{x any}
EOF
#
# @0 2 <-- {y any}
# 
incref
send <<EOF
senp{ to="$siena0" method="SUB" ref=$ref subscriber="$client/2"}
filter{y any}
EOF
#
# @1 3 <-- {z any}
#
incref
send <<EOF
senp{ to="$siena1" method="SUB" ref=$ref subscriber="$client/3"}
filter{z any}
EOF
#
# @1 {x = 1 y = 1} --> 1, 2, 3
#
incref
send <<EOF
senp{ to="$siena1" method="PUB" ref=$ref}
event{ x=1 y=1}
EOF
expect <<EOF
senp{ from="$siena0" method="PUB" ref=$ref to="$client/1" }
event{ x=1 y=1 }
senp{ from="$siena0" method="PUB" ref=$ref to="$client/2" }
event{ x=1 y=1 }
EOF
#
# @2 {x = 1 z = 3} --> 1, 3
#
incref
send <<EOF
senp{ to="$siena2" method="PUB" ref=$ref}
event{x = 1 z = 3}
EOF
expect <<EOF
senp{ from="$siena0" method="PUB" ref=$ref to="$client/1" }
event{ x=1 z=3 }
senp{ from="$siena1" method="PUB" ref=$ref to="$client/3" }
event{ x=1 z=3 }
EOF
#
#
# @0 4 <-- {x > 0 y > 0}
#
incref
send <<EOF
senp{ to="$siena0" method="SUB" ref=$ref subscriber="$client/4"}
filter{x > 0 y > 0}
EOF
#
# @0 5 <-- {y > 0 z > 0}
#
incref
send <<EOF
senp{ to="$siena0" method="SUB" ref=$ref subscriber="$client/5"}
filter{y > 0 z > 0}
EOF
#
# @2 6 <-- {x > 0 z > 0}
#
incref
send <<EOF
senp{ to="$siena2" method="SUB" ref=$ref subscriber="$client/6"}
filter{x > 0 z > 0}
EOF
#
# @1 {x = 1 y = 2} --> 1, 2, 4
#
incref
send <<EOF
senp{ to="$siena1" method="PUB" ref=$ref}
event{x = 1 y = 2}
EOF
expect <<EOF
senp{ from="$siena0" method="PUB" ref=$ref to="$client/1" }
event{ x=1 y=2 }
senp{ from="$siena0" method="PUB" ref=$ref to="$client/2" }
event{ x=1 y=2 }
senp{ from="$siena0" method="PUB" ref=$ref to="$client/4" }
event{ x=1 y=2 }
EOF
#
# @2 {x = 1 y = 3} --> 1, 2, 4
#
incref
send <<EOF
senp{ to="$siena2" method="PUB" ref=$ref}
event{x = 1 y = 3}
EOF
expect <<EOF
senp{ from="$siena0" method="PUB" ref=$ref to="$client/1" }
event{ x=1 y=3 }
senp{ from="$siena0" method="PUB" ref=$ref to="$client/2" }
event{ x=1 y=3 }
senp{ from="$siena0" method="PUB" ref=$ref to="$client/4" }
event{ x=1 y=3 }
EOF
#
#
incref
send <<EOF
senp{ to="$siena0" method="PUB" ref=$ref}
event{z = 3}
EOF
expect <<EOF
senp{ from="$siena1" method="PUB" ref=$ref to="$client/3" }
event{ z=3 }
EOF
#
# @1 7 <-- {x > 0 y > 0 z > 0}
#
incref
send <<EOF
senp{ to="$siena1" method="SUB" ref=$ref subscriber="$client/7"}
filter{x > 0 y > 0 z > 0}
EOF
#
# @2 {x = 1 y = 2 z = 3} --> 1, 2, 3, 4, 5, 6, 7
#
incref
send <<EOF
senp{ to="$siena2" method="PUB" ref=$ref}
event{x = 1 y = 2 z = 3}
EOF
expect <<EOF
senp{ from="$siena0" method="PUB" ref=$ref to="$client/1" }
event{ x=1 y=2 z=3 }
senp{ from="$siena0" method="PUB" ref=$ref to="$client/2" }
event{ x=1 y=2 z=3 }
senp{ from="$siena1" method="PUB" ref=$ref to="$client/3" }
event{ x=1 y=2 z=3 }
senp{ from="$siena0" method="PUB" ref=$ref to="$client/4" }
event{ x=1 y=2 z=3 }
senp{ from="$siena0" method="PUB" ref=$ref to="$client/5" }
event{ x=1 y=2 z=3 }
senp{ from="$siena2" method="PUB" ref=$ref to="$client/6" }
event{ x=1 y=2 z=3 }
senp{ from="$siena1" method="PUB" ref=$ref to="$client/7" }
event{ x=1 y=2 z=3 }
EOF
#
# @0 5 -X- {z > 0} (in fact {y > 0 z > 0}) 
#
incref
send <<EOF
senp{ to="$siena0" method="UNS" ref=$ref subscriber="$client/5"}
filter{z > 0}
EOF
##
##
sleep 4
shutdownservers force
sleep 10
$TESTHOME/topology3.sh
. $topology_info
sleep 5
##
##
#
# @1 {y = 2 z = 3} --> 2, 3
#
incref
send <<EOF
senp{ to="$siena1" method="PUB" ref=$ref}
event{y = 2 z = 3}
EOF
expect <<EOF
senp{ from="$siena0" method="PUB" ref=$ref to="$client/2" }
event{ y=2 z=3 }
senp{ from="$siena1" method="PUB" ref=$ref to="$client/3" }
event{ y=2 z=3 }
EOF
#
# @0 8 <-- {y > 0 z > 0}
#
incref
send <<EOF
senp{ to="$siena0" method="SUB" ref=$ref subscriber="$client/8"}
filter{y>0 z>0}
EOF
#
# @0 {y = 2 z = 3} --> 2, 3, 8
#
incref
send <<EOF
senp{ to="$siena0" method="PUB" ref=$ref}
event{y = 2 z = 3}
EOF
expect <<EOF
senp{ from="$siena0" method="PUB" ref=$ref to="$client/2" }
event{ y=2 z=3 }
senp{ from="$siena1" method="PUB" ref=$ref to="$client/3" }
event{ y=2 z=3 }
senp{ from="$siena0" method="PUB" ref=$ref to="$client/8" }
event{ y=2 z=3 }
EOF
#
#
# @0 9 <-- {x > 0 y > 0}
#
incref
send <<EOF
senp{ to="$siena0" method="SUB" ref=$ref subscriber="$client/9"}
filter{y>0 x>0}
EOF
#
# @2 {y = 2 z = 3} --> 1, 2, 4, 9
#
incref
send <<EOF
senp{ to="$siena2" method="PUB" ref=$ref}
event{x = 2 y = 3}
EOF
expect <<EOF
senp{ from="$siena0" method="PUB" ref=$ref to="$client/1" }
event{ x=2 y=3 }
senp{ from="$siena0" method="PUB" ref=$ref to="$client/2" }
event{ x=2 y=3 }
senp{ from="$siena0" method="PUB" ref=$ref to="$client/4" }
event{ x=2 y=3 }
senp{ from="$siena0" method="PUB" ref=$ref to="$client/9" }
event{ x=2 y=3 }
EOF
#
# 4 -X- {x any y any} (in fact x>0 y>0)
#
incref
send <<EOF
senp{ to="$siena0" method="UNS" ref=$ref subscriber="$client/4"}
filter{y any x any}
EOF
sleep 2
#
# @1 {x = 2 y = 3} --> 1, 2, 9
#
incref
send <<EOF
senp{ to="$siena1" method="PUB" ref=$ref}
event{x = 2 y = 3}
EOF
expect <<EOF
senp{ from="$siena0" method="PUB" ref=$ref to="$client/1" }
event{ x=2 y=3 }
senp{ from="$siena0" method="PUB" ref=$ref to="$client/2" }
event{ x=2 y=3 }
senp{ from="$siena0" method="PUB" ref=$ref to="$client/9" }
event{ x=2 y=3 }
EOF
#
# @0 10 <-- {x>0 y>0 z>0 a="A"}
#
incref
send <<EOF
senp{ to="$siena0" method="SUB" ref=$ref subscriber="$client/10"}
filter{x>0 y>0 z>0 a="A"}
EOF
#
# @0 11 <-- {x>0 y>0 z>0 a="B"}
#
incref
send <<EOF
senp{ to="$siena0" method="SUB" ref=$ref subscriber="$client/11"}
filter{x>0 y>0 z>0 a="B"}
EOF
#
# @0 {x=2 y=3 z=4 a="A"} --> 1, 2, 3, 6, 7, 8, 9, 10
#
incref
send <<EOF
senp{ to="$siena0" method="PUB" ref=$ref}
event{x=2 y=3 z=4 a="A"}
EOF
expect <<EOF
senp{ from="$siena0" method="PUB" ref=$ref to="$client/1" }
event{ a="A" x=2 y=3 z=4 }
senp{ from="$siena0" method="PUB" ref=$ref to="$client/10" }
event{ a="A" x=2 y=3 z=4 }
senp{ from="$siena0" method="PUB" ref=$ref to="$client/2" }
event{ a="A" x=2 y=3 z=4 }
senp{ from="$siena1" method="PUB" ref=$ref to="$client/3" }
event{ a="A" x=2 y=3 z=4 }
senp{ from="$siena2" method="PUB" ref=$ref to="$client/6" }
event{ a="A" x=2 y=3 z=4 }
senp{ from="$siena1" method="PUB" ref=$ref to="$client/7" }
event{ a="A" x=2 y=3 z=4 }
senp{ from="$siena0" method="PUB" ref=$ref to="$client/8" }
event{ a="A" x=2 y=3 z=4 }
senp{ from="$siena0" method="PUB" ref=$ref to="$client/9" }
event{ a="A" x=2 y=3 z=4 }
EOF
#
# @2 {x=2 y=3 z=4 a="B"} --> 1, 2, 3, 6, 7, 8, 9, 11
#
incref
send <<EOF
senp{ to="$siena2" method="PUB" ref=$ref}
event{x=2 y=3 z=4 a="B"}
EOF
expect <<EOF
senp{ from="$siena0" method="PUB" ref=$ref to="$client/1" }
event{ a="B" x=2 y=3 z=4 }
senp{ from="$siena0" method="PUB" ref=$ref to="$client/11" }
event{ a="B" x=2 y=3 z=4 }
senp{ from="$siena0" method="PUB" ref=$ref to="$client/2" }
event{ a="B" x=2 y=3 z=4 }
senp{ from="$siena1" method="PUB" ref=$ref to="$client/3" }
event{ a="B" x=2 y=3 z=4 }
senp{ from="$siena2" method="PUB" ref=$ref to="$client/6" }
event{ a="B" x=2 y=3 z=4 }
senp{ from="$siena1" method="PUB" ref=$ref to="$client/7" }
event{ a="B" x=2 y=3 z=4 }
senp{ from="$siena0" method="PUB" ref=$ref to="$client/8" }
event{ a="B" x=2 y=3 z=4 }
senp{ from="$siena0" method="PUB" ref=$ref to="$client/9" }
event{ a="B" x=2 y=3 z=4 }
EOF
#
# @1 7 -X- {x>0 y>0 z>0} (in fact exactly x>0 y>0 z>0)
#
incref
send <<EOF
senp{ to="$siena1" method="UNS" ref=$ref subscriber="$client/7"}
filter{x>0 y>0 z>0}
EOF
#
# @2 {x=2 y=3 z=4 a="A"} --> 1, 2, 3, 6, 8, 9, 10
#
incref
send <<EOF
senp{ to="$siena2" method="PUB" ref=$ref}
event{x=2 y=3 z=4 a="A"}
EOF
expect <<EOF
senp{ from="$siena0" method="PUB" ref=$ref to="$client/1" }
event{ a="A" x=2 y=3 z=4 }
senp{ from="$siena0" method="PUB" ref=$ref to="$client/10" }
event{ a="A" x=2 y=3 z=4 }
senp{ from="$siena0" method="PUB" ref=$ref to="$client/2" }
event{ a="A" x=2 y=3 z=4 }
senp{ from="$siena1" method="PUB" ref=$ref to="$client/3" }
event{ a="A" x=2 y=3 z=4 }
senp{ from="$siena2" method="PUB" ref=$ref to="$client/6" }
event{ a="A" x=2 y=3 z=4 }
senp{ from="$siena0" method="PUB" ref=$ref to="$client/8" }
event{ a="A" x=2 y=3 z=4 }
senp{ from="$siena0" method="PUB" ref=$ref to="$client/9" }
event{ a="A" x=2 y=3 z=4 }
EOF
#
# @1 {x=2 y=3 z=4} --> 1, 2, 3, 6, 8, 9, 10
#
incref
send <<EOF
senp{ to="$siena1" method="PUB" ref=$ref}
event{x=2 y=3 z=4}
EOF
expect <<EOF
senp{ from="$siena0" method="PUB" ref=$ref to="$client/1" }
event{ x=2 y=3 z=4 }
senp{ from="$siena0" method="PUB" ref=$ref to="$client/2" }
event{ x=2 y=3 z=4 }
senp{ from="$siena1" method="PUB" ref=$ref to="$client/3" }
event{ x=2 y=3 z=4 }
senp{ from="$siena2" method="PUB" ref=$ref to="$client/6" }
event{ x=2 y=3 z=4 }
senp{ from="$siena0" method="PUB" ref=$ref to="$client/8" }
event{ x=2 y=3 z=4 }
senp{ from="$siena0" method="PUB" ref=$ref to="$client/9" }
event{ x=2 y=3 z=4 }
EOF
#
# @0 12 <-- {a any}
#
incref
send <<EOF
senp{ to="$siena0" method="SUB" ref=$ref subscriber="$client/12"}
filter{a any}
EOF
#
# @0 {x=2 a="A"} --> 1, 12
#
incref
send <<EOF
senp{ to="$siena0" method="PUB" ref=$ref}
event{x=2 a="A"}
EOF
expect <<EOF
senp{ from="$siena0" method="PUB" ref=$ref to="$client/1" }
event{ a="A" x=2 }
senp{ from="$siena0" method="PUB" ref=$ref to="$client/12" }
event{ a="A" x=2 }
EOF
#
# @0 {x=2 y=5 a="A"} --> 1, 2, 9, 12
#
incref
send <<EOF
senp{ to="$siena0" method="PUB" ref=$ref}
event{x=2 y=5 a="A"}
EOF
expect <<EOF
senp{ from="$siena0" method="PUB" ref=$ref to="$client/1" }
event{ a="A" x=2 y=5 }
senp{ from="$siena0" method="PUB" ref=$ref to="$client/12" }
event{ a="A" x=2 y=5 }
senp{ from="$siena0" method="PUB" ref=$ref to="$client/2" }
event{ a="A" x=2 y=5 }
senp{ from="$siena0" method="PUB" ref=$ref to="$client/9" }
event{ a="A" x=2 y=5 }
EOF
#
# @0 1 -X- {x any} (in fact exactly x any)
#
incref
send <<EOF
senp{ to="$siena0" method="UNS" ref=$ref subscriber="$client/1"}
filter{x any}
EOF
#
#
# @1 {x=2 z=7 a="X"} --> 3, 6, 12
#
incref
send <<EOF
senp{ to="$siena1" method="PUB" ref=$ref}
event{x=2 z=7 a="X"}
EOF
expect <<EOF
senp{ from="$siena0" method="PUB" ref=$ref to="$client/12" }
event{ a="X" x=2 z=7 }
senp{ from="$siena1" method="PUB" ref=$ref to="$client/3" }
event{ a="X" x=2 z=7 }
senp{ from="$siena2" method="PUB" ref=$ref to="$client/6" }
event{ a="X" x=2 z=7 }
EOF
#
# @0 13 <-- {z any}
#
incref
send <<EOF
senp{ to="$siena0" method="SUB" ref=$ref subscriber="$client/13"}
filter{z any}
EOF
#
# @2 {x=2 z=7 a="X"} --> 3, 6, 12, 13
#
incref
send <<EOF
senp{ to="$siena2" method="PUB" ref=$ref}
event{x=2 z=7 a="X"}
EOF
expect <<EOF
senp{ from="$siena0" method="PUB" ref=$ref to="$client/12" }
event{ a="X" x=2 z=7 }
senp{ from="$siena0" method="PUB" ref=$ref to="$client/13" }
event{ a="X" x=2 z=7 }
senp{ from="$siena1" method="PUB" ref=$ref to="$client/3" }
event{ a="X" x=2 z=7 }
senp{ from="$siena2" method="PUB" ref=$ref to="$client/6" }
event{ a="X" x=2 z=7 }
EOF
#
# @1 {x=2 z=7 a="X"} --> 3, 6, 12, 13
#
incref
send <<EOF
senp{ to="$siena1" method="PUB" ref=$ref}
event{x=2 z=7 a="X"}
EOF
expect <<EOF
senp{ from="$siena0" method="PUB" ref=$ref to="$client/12" }
event{ a="X" x=2 z=7 }
senp{ from="$siena0" method="PUB" ref=$ref to="$client/13" }
event{ a="X" x=2 z=7 }
senp{ from="$siena1" method="PUB" ref=$ref to="$client/3" }
event{ a="X" x=2 z=7 }
senp{ from="$siena2" method="PUB" ref=$ref to="$client/6" }
event{ a="X" x=2 z=7 }
EOF
#
# @0 14 <-- {z any}
#
incref
send <<EOF
senp{ to="$siena0" method="SUB" ref=$ref subscriber="$client/14"}
filter{z any}
EOF
#
# @1 {z=7} --> 3, 13, 14
#
incref
send <<EOF
senp{ to="$siena1" method="PUB" ref=$ref}
event{ z=7 }
EOF
expect <<EOF
senp{ from="$siena0" method="PUB" ref=$ref to="$client/13" }
event{ z=7 }
senp{ from="$siena1" method="PUB" ref=$ref to="$client/3" }
event{ z=7 }
senp{ from="$siena0" method="PUB" ref=$ref to="$client/14" }
event{ z=7 }
EOF
#
# @0 {z=7} --> 3, 13, 14
#
incref
send <<EOF
senp{ to="$siena0" method="PUB" ref=$ref}
event{ z=7 }
EOF
expect <<EOF
senp{ from="$siena0" method="PUB" ref=$ref to="$client/13" }
event{ z=7 }
senp{ from="$siena1" method="PUB" ref=$ref to="$client/3" }
event{ z=7 }
senp{ from="$siena0" method="PUB" ref=$ref to="$client/14" }
event{ z=7 }
EOF
#
# @1 3 -X- {z any}
#
incref
send <<EOF
senp{ to="$siena1" method="UNS" ref=$ref subscriber="$client/3"}
filter{z any}
EOF
#
# @1 {z=7} --> 13, 14
#
incref
send <<EOF
senp{ to="$siena1" method="PUB" ref=$ref}
event{ z=7 }
EOF
expect <<EOF
senp{ from="$siena0" method="PUB" ref=$ref to="$client/13" }
event{ z=7 }
senp{ from="$siena0" method="PUB" ref=$ref to="$client/14" }
event{ z=7 }
EOF
#
#
# @2 {z=7} --> 13, 14
#
incref
send <<EOF
senp{ to="$siena2" method="PUB" ref=$ref}
event{ z=7 }
EOF
expect <<EOF
senp{ from="$siena0" method="PUB" ref=$ref to="$client/13" }
event{ z=7 }
senp{ from="$siena0" method="PUB" ref=$ref to="$client/14" }
event{ z=7 }
EOF
#
# @0 13 -X- {z any}
#
incref
send <<EOF
senp{ to="$siena0" method="UNS" ref=$ref subscriber="$client/13"}
filter{z any}
EOF
#
# @2 {z=7} --> 14
#
incref
send <<EOF
senp{ to="$siena2" method="PUB" ref=$ref}
event{ z=7 }
EOF
expect <<EOF
senp{ from="$siena0" method="PUB" ref=$ref to="$client/14" }
event{ z=7 }
EOF
#
# @0 14 -X- {z any}
#
incref
send <<EOF
senp{ to="$siena0" method="UNS" ref=$ref subscriber="$client/14"}
filter{z any}
EOF
#
# @2 {z=8} --> 
#
incref
send <<EOF
senp{ to="$siena2" method="PUB" ref=$ref}
event{ z=8 }
EOF
#
# @1 {x=2 z=7 a="Y"} --> 6, 12
#
incref
send <<EOF
senp{ to="$siena1" method="PUB" ref=$ref}
event{x=2 z=7 a="Y"}
EOF
expect <<EOF
senp{ from="$siena0" method="PUB" ref=$ref to="$client/12" }
event{ a="Y" x=2 z=7 }
senp{ from="$siena2" method="PUB" ref=$ref to="$client/6" }
event{ a="Y" x=2 z=7 }
EOF
#
# @2 6 -X-
#
incref
send<<EOF
senp{ to="$siena2" method="BYE" ref=$ref subscriber="$client/6" }
EOF
#
# @1 {x=2 z=7 a="Y"} --> 12
#
incref
send <<EOF
senp{ to="$siena1" method="PUB" ref=$ref}
event{x=2 z=7 a="Y"}
EOF
expect <<EOF
senp{ from="$siena0" method="PUB" ref=$ref to="$client/12" }
event{ a="Y" x=2 z=7 }
EOF
#
# @1 15 <-- { x>0 y>0 }
#
incref
send<<EOF
senp{ to="$siena1" method="SUB" ref=$ref subscriber="$client/15" }
filter{ x>0 y>0 }
EOF
#
# @2 {x=2 y=17} --> 15, 2, 9 
#
incref
send <<EOF
senp{ to="$siena2" method="PUB" ref=$ref}
event{x=2 y=17}
EOF
expect <<EOF
senp{ from="$siena1" method="PUB" ref=$ref to="$client/15" }
event{ x=2 y=17 }
senp{ from="$siena0" method="PUB" ref=$ref to="$client/2" }
event{ x=2 y=17 }
senp{ from="$siena0" method="PUB" ref=$ref to="$client/9" }
event{ x=2 y=17 }
EOF
#
# @0 2 -X-
#
incref
send<<EOF
senp{ to="$siena0" method="BYE" ref=$ref subscriber="$client/2" }
EOF
#
# @0 9 -X-
#
incref
send<<EOF
senp{ to="$siena0" method="BYE" ref=$ref subscriber="$client/9" }
EOF
#
# @2 {x=2 y=18} --> 15 
#
incref
send <<EOF
senp{ to="$siena2" method="PUB" ref=$ref}
event{x=2 y=18}
EOF
expect <<EOF
senp{ from="$siena1" method="PUB" ref=$ref to="$client/15" }
event{ x=2 y=18 }
EOF
#
# @1 {x=2 y=18 z=1 a="A"} --> 15, 10, 8, 12
#
incref
send <<EOF
senp{ to="$siena2" method="PUB" ref=$ref}
event{x=2 y=18 z=1 a="A"}
EOF
expect <<EOF
senp{ from="$siena1" method="PUB" ref=$ref to="$client/15" }
event{x=2 y=18 z=1 a="A"}
senp{ from="$siena0" method="PUB" ref=$ref to="$client/10" }
event{x=2 y=18 z=1 a="A"}
senp{ from="$siena0" method="PUB" ref=$ref to="$client/12" }
event{x=2 y=18 z=1 a="A"}
senp{ from="$siena0" method="PUB" ref=$ref to="$client/8" }
event{x=2 y=18 z=1 a="A"}
EOF
#
# @0 10 -X- {x > 0} (actually {x>0 y>0 z>0 a="A"})
#
incref
send<<EOF
senp{to="$siena0" method="UNS" ref=$ref subscriber="$client/10"}
filter{x>0}
EOF
#
# @0 12 -X-
#
incref
send<<EOF
senp{to="$siena0" method="BYE" ref=$ref subscriber="$client/12"}
EOF
#
# @2 {x=2 y=20 z=1 a="A"} --> 15, 8
#
incref
send <<EOF
senp{ to="$siena2" method="PUB" ref=$ref}
event{x=2 y=20 z=1 a="A"}
EOF
expect <<EOF
senp{ from="$siena1" method="PUB" ref=$ref to="$client/15" }
event{x=2 y=20 z=1 a="A"}
senp{ from="$siena0" method="PUB" ref=$ref to="$client/8" }
event{x=2 y=20 z=1 a="A"}
EOF
#
# @0 8 -X-
#
incref
send<<EOF
senp{to="$siena0" method="BYE" ref=$ref subscriber="$client/8"}
EOF
#
# @0 11 -X-
#
incref
send<<EOF
senp{to="$siena0" method="BYE" ref=$ref subscriber="$client/11"}
EOF
#
# @2 {x=2 y=20 z=1 a="A"} --> 15
#
incref
send <<EOF
senp{ to="$siena2" method="PUB" ref=$ref}
event{x=2 y=20 z=1 a="A"}
EOF
expect <<EOF
senp{ from="$siena1" method="PUB" ref=$ref to="$client/15" }
event{x=2 y=20 z=1 a="A"}
EOF
#
# @1 {x=2 y=21 z=1 a="A"} --> 15
#
incref
send <<EOF
senp{ to="$siena1" method="PUB" ref=$ref}
event{x=2 y=21 z=1 a="A"}
EOF
expect <<EOF
senp{ from="$siena1" method="PUB" ref=$ref to="$client/15" }
event{x=2 y=21 z=1 a="A"}
EOF
#
# @2 15 -X-
#
incref
send<<EOF
senp{to="$siena1" method="BYE" ref=$ref subscriber="$client/15"}
EOF
#
# @2 {x=2 y=20 z=1 a="A"} --> 15
#
incref
send <<EOF
senp{ to="$siena2" method="PUB" ref=$ref}
event{x=2 y=20 z=1 a="A"}
EOF
#
#
# -------------------- TEST ENDS HERE ---------------------
#
closetest $*
