#!/bin/sh
#
#  This file is part of Siena, a wide-area event notification system.
#  See http://www.cs.colorado.edu/serl/dot/siena.html
#
#  Author: Antonio Carzaniga <carzanig@cs.colorado.edu>
#  See the file AUTHORS for full details. 
#
#  Copyright (C) 1998-1999 University of Colorado
#
#  This program is free software; you can redistribute it and/or
#  modify it under the terms of the GNU General Public License
#  as published by the Free Software Foundation; either version 2
#  of the License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software
#  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307,
#  USA, or send email to serl@cs.colorado.edu.
#
#
# $Id: test_string.sh,v 1.1 2002/06/10 20:19:15 carzanig Exp $
#
. ./config
. $srcdir/base.sh
#
cat<<EOF
Tested Feature:		string filters

Topology:		4 servers, 1 object, 1 party
Interface functions:	subscribe, unsubscribe, publish
Notification classes:	single attribute
Attribute types:	string, integer, boolean, float
Filter classes:		single attribute, single constraint
Filter types:		string
Filter operators:	= != > < >= <= >* *< *
EOF
#
# opentest <topology> [notopology | restart]
#
opentest 4 $*
#
# --------------- TEST BEGINS HERE -----------------
#
#
#
# @0 1 <-- {x="ABCDEFuvxyz"}
#
incref
send<<EOF
senp{to="$siena0" method="SUB" ref=$ref subscriber="$client/1"}
filter{x="ABCDEFuvxyz"}
EOF
#
#
incref
send<<EOF
senp{to="$siena1" method="PUB" ref=$ref}
event{x="ABCDEFuvxyz"}
EOF
expect<<EOF
senp{from="$siena0" method="PUB" ref=$ref to="$client/1" }
event{x="ABCDEFuvxyz"}
EOF
#
#
incref
send<<EOF
senp{to="$siena1" method="PUB" ref=$ref}
event{x="ABCDEFuvxy"}
EOF
#
#
incref
send<<EOF
senp{to="$siena2" method="PUB" ref=$ref}
event{x="BCDEFuvxyz"}
EOF
#
#
incref
send<<EOF
senp{to="$siena3" method="PUB" ref=$ref}
event{x="ABCDEFuvxyz123"}
EOF
#
#
incref
send<<EOF
senp{to="$siena0" method="PUB" ref=$ref}
event{x=1234}
EOF
#
#
incref
send<<EOF
senp{to="$siena1" method="PUB" ref=$ref}
event{x=false}
EOF
#
#
incref
send<<EOF
senp{to="$siena2" method="PUB" ref=$ref}
event{x=1.234}
EOF
#
#
incref
send<<EOF
senp{to="$siena0" method="UNS" ref=$ref subscriber="$client/1"}
filter{x="ABCDEFuvxyz"}
EOF
#
# @1 1 <-- {x != "ABCDEFuvxyz"}
#
incref
send<<EOF
senp{to="$siena1" method="SUB" ref=$ref subscriber="$client/1"}
filter{x != "ABCDEFuvxyz"}
EOF
#
#
incref
send<<EOF
senp{to="$siena0" method="PUB" ref=$ref}
event{x="Ciao"}
EOF
expect<<EOF
senp{from="$siena1" method="PUB" ref=$ref to="$client/1" }
event{x="Ciao"}
EOF
#
#
incref
send<<EOF
senp{to="$siena1" method="PUB" ref=$ref}
event{x="ABCDEFuvxyz"}
EOF
#
#
incref
send<<EOF
senp{to="$siena2" method="PUB" ref=$ref}
event{x="ABCDEFuvxyz1"}
EOF
expect<<EOF
senp{from="$siena1" method="PUB" ref=$ref to="$client/1" }
event{x="ABCDEFuvxyz1"}
EOF
#
#
incref
send<<EOF
senp{to="$siena3" method="PUB" ref=$ref}
event{x="zABCDEFuvxyz"}
EOF
expect<<EOF
senp{from="$siena1" method="PUB" ref=$ref to="$client/1" }
event{x="zABCDEFuvxyz"}
EOF
#
#
incref
send<<EOF
senp{to="$siena1" method="PUB" ref=$ref}
event{x=1234}
EOF
expect<<EOF
senp{from="$siena1" method="PUB" ref=$ref to="$client/1" }
event{x=1234}
EOF
#
#
incref
send<<EOF
senp{to="$siena0" method="PUB" ref=$ref}
event{x=false}
EOF
expect<<EOF
senp{from="$siena1" method="PUB" ref=$ref to="$client/1" }
event{x=false}
EOF
#
incref
send<<EOF
senp{to="$siena2" method="PUB" ref=$ref}
event{x=true}
EOF
expect<<EOF
senp{from="$siena1" method="PUB" ref=$ref to="$client/1" }
event{x=true}
EOF
#
#
incref
send<<EOF
senp{to="$siena3" method="PUB" ref=$ref}
event{x=1.234}
EOF
expect<<EOF
senp{from="$siena1" method="PUB" ref=$ref to="$client/1" }
event{x=1.234}
EOF
#
#
incref
send<<EOF
senp{to="$siena1" method="UNS" ref=$ref subscriber="$client/1"}
filter{x != "ABCDEFuvxyz"}
EOF
#
# @2 1 <-- {x > "ABCDEFuvxyz"}
#
incref
send<<EOF
senp{to="$siena2" method="SUB" ref=$ref subscriber="$client/1"}
filter{x > "ABCDEFuvxyz"}
EOF
#
#
incref
send<<EOF
senp{to="$siena0" method="PUB" ref=$ref}
event{x = "ABCDEFuvxyz"}
EOF
#
#
incref
send<<EOF
senp{to="$siena0" method="PUB" ref=$ref}
event{x = "ABCDEFuvxy"}
EOF
#
#
incref
send<<EOF
senp{to="$siena1" method="PUB" ref=$ref}
event{x = "BCDEFuvxyz"}
EOF
expect<<EOF
senp{from="$siena2" method="PUB" ref=$ref to="$client/1" }
event{x="BCDEFuvxyz"}
EOF
#
#
incref
send<<EOF
senp{to="$siena2" method="PUB" ref=$ref}
event{x="ABCDEFuvxyz123"}
EOF
expect<<EOF
senp{from="$siena2" method="PUB" ref=$ref to="$client/1" }
event{x="ABCDEFuvxyz123"}
EOF
#
#
incref
send<<EOF
senp{to="$siena3" method="PUB" ref=$ref}
event{x="ABCDEFabcd123"}
EOF
#
#
incref
send<<EOF
senp{to="$siena0" method="PUB" ref=$ref}
event{x=1234}
EOF
#
#
incref
send<<EOF
senp{to="$siena1" method="PUB" ref=$ref}
event{x=false}
EOF
#
#
incref
send<<EOF
senp{to="$siena2" method="PUB" ref=$ref}
event{x=1.234}
EOF
#
#
incref
send<<EOF
senp{to="$siena2" method="UNS" ref=$ref subscriber="$client/1"}
filter{x > "ABCDEFuvxyz"}
EOF
#
# @3 1 <-- {x < "ABCDEFuvxyz"}
#
incref
send<<EOF
senp{to="$siena3" method="SUB" ref=$ref subscriber="$client/1"}
filter{x < "ABCDEFuvxyz"}
EOF
#
#
incref
send<<EOF
senp{to="$siena0" method="PUB" ref=$ref}
event{x = "ABCDEFuvxyz"}
EOF
#
#
incref
send<<EOF
senp{to="$siena1" method="PUB" ref=$ref}
event{x = "ABCDEFuvxy"}
EOF
expect<<EOF
senp{from="$siena3" method="PUB" ref=$ref to="$client/1" }
event{x="ABCDEFuvxy"}
EOF
#
#
incref
send<<EOF
senp{to="$siena0" method="PUB" ref=$ref}
event{x = "BCDEFuvxyz"}
EOF
#
#
incref
send<<EOF
senp{to="$siena2" method="PUB" ref=$ref}
event{x="ABCDEFuvxyz123"}
EOF
#
#
incref
send<<EOF
senp{to="$siena0" method="PUB" ref=$ref}
event{x="ABCDEFabcd123"}
EOF
expect<<EOF
senp{from="$siena3" method="PUB" ref=$ref to="$client/1" }
event{x="ABCDEFabcd123"}
EOF
#
#
incref
send<<EOF
senp{to="$siena0" method="PUB" ref=$ref}
event{x=1234}
EOF
#
#
incref
send<<EOF
senp{to="$siena0" method="PUB" ref=$ref}
event{x=false}
EOF
#
#
incref
send<<EOF
senp{to="$siena0" method="PUB" ref=$ref}
event{x=1.234}
EOF
#
#
incref
send<<EOF
senp{to="$siena3" method="UNS" ref=$ref subscriber="$client/1"}
filter{x < "ABCDEFuvxyz"}
EOF
#
# @0 1 <-- {x >= "ABCDEFuvxyz"}
#
incref
send<<EOF
senp{to="$siena0" method="SUB" ref=$ref subscriber="$client/1"}
filter{x >= "ABCDEFuvxyz"}
EOF
#
#
incref
send<<EOF
senp{to="$siena3" method="PUB" ref=$ref}
event{x = "ABCDEFuvxyz"}
EOF
expect<<EOF
senp{from="$siena0" method="PUB" ref=$ref to="$client/1" }
event{x="ABCDEFuvxyz"}
EOF
#
#
incref
send<<EOF
senp{to="$siena2" method="PUB" ref=$ref}
event{x = "ABCDEFuvxy"}
EOF
#
#
incref
send<<EOF
senp{to="$siena1" method="PUB" ref=$ref}
event{x = "BCDEFuvxyz"}
EOF
expect<<EOF
senp{from="$siena0" method="PUB" ref=$ref to="$client/1" }
event{x="BCDEFuvxyz"}
EOF
#
#
incref
send<<EOF
senp{to="$siena3" method="PUB" ref=$ref}
event{x="ABCDEFuvxyz123"}
EOF
expect<<EOF
senp{from="$siena0" method="PUB" ref=$ref to="$client/1" }
event{x="ABCDEFuvxyz123"}
EOF
#
#
incref
send<<EOF
senp{to="$siena0" method="PUB" ref=$ref}
event{x="ABCDEFabcd123"}
EOF
#
#
incref
send<<EOF
senp{to="$siena0" method="PUB" ref=$ref}
event{x=1234}
EOF
#
#
incref
send<<EOF
senp{to="$siena2" method="PUB" ref=$ref}
event{x=false}
EOF
#
#
incref
send<<EOF
senp{to="$siena1" method="PUB" ref=$ref}
event{x=1.234}
EOF
#
#
incref
send<<EOF
senp{to="$siena0" method="UNS" ref=$ref subscriber="$client/1"}
filter{x >= "ABCDEFuvxyz"}
EOF
#
# @1 1 <-- {x <= "ABCDEFuvxyz"}
#
incref
send<<EOF
senp{to="$siena1" method="SUB" ref=$ref subscriber="$client/1"}
filter{x <= "ABCDEFuvxyz"}
EOF
#
#
incref
send<<EOF
senp{to="$siena0" method="PUB" ref=$ref}
event{x = "ABCDEFuvxyz"}
EOF
expect<<EOF
senp{from="$siena1" method="PUB" ref=$ref to="$client/1" }
event{x="ABCDEFuvxyz"}
EOF
#
#
incref
send<<EOF
senp{to="$siena2" method="PUB" ref=$ref}
event{x = "ABCDEFuvxy"}
EOF
expect<<EOF
senp{from="$siena1" method="PUB" ref=$ref to="$client/1" }
event{x="ABCDEFuvxy"}
EOF
#
#
incref
send<<EOF
senp{to="$siena0" method="PUB" ref=$ref}
event{x = "BCDEFuvxyz"}
EOF
#
#
incref
send<<EOF
senp{to="$siena2" method="PUB" ref=$ref}
event{x="ABCDEFuvxyz123"}
EOF
#
#
incref
send<<EOF
senp{to="$siena3" method="PUB" ref=$ref}
event{x="ABCDEFabcd123"}
EOF
expect<<EOF
senp{from="$siena1" method="PUB" ref=$ref to="$client/1" }
event{x="ABCDEFabcd123"}
EOF
#
#
incref
send<<EOF
senp{to="$siena3" method="PUB" ref=$ref}
event{x=1234}
EOF
#
#
incref
send<<EOF
senp{to="$siena2" method="PUB" ref=$ref}
event{x=false}
EOF
#
#
incref
send<<EOF
senp{to="$siena0" method="PUB" ref=$ref}
event{x=1.234}
EOF
#
#
incref
send<<EOF
senp{to="$siena1" method="UNS" ref=$ref subscriber="$client/1"}
filter{x <= "ABCDEFuvxyz"}
EOF
#
# @0 1 <-- {x *< "ABCDEFuvxyz"}
#
incref
send<<EOF
senp{to="$siena0" method="SUB" ref=$ref subscriber="$client/1"}
filter{x *< "ABCDEFuvxyz"}
EOF
#
#
incref
send<<EOF
senp{to="$siena0" method="PUB" ref=$ref}
event{x = "ABCDEFuvxyz"}
EOF
expect<<EOF
senp{from="$siena0" method="PUB" ref=$ref to="$client/1" }
event{x="ABCDEFuvxyz"}
EOF
#
#
incref
send<<EOF
senp{to="$siena0" method="PUB" ref=$ref}
event{x = "ABCDEFuvxy"}
EOF
#
#
incref
send<<EOF
senp{to="$siena3" method="PUB" ref=$ref}
event{x = "BCDEFuvxyz"}
EOF
#
#
incref
send<<EOF
senp{to="$siena1" method="PUB" ref=$ref}
event{x="ABCDEFuvxyz123"}
EOF
#
#
incref
send<<EOF
senp{to="$siena2" method="PUB" ref=$ref}
event{x="321ABCDEFuvxyz"}
EOF
expect<<EOF
senp{from="$siena0" method="PUB" ref=$ref to="$client/1" }
event{x="321ABCDEFuvxyz"}
EOF
#
#
incref
send<<EOF
senp{to="$siena0" method="PUB" ref=$ref}
event{x=1234}
EOF
#
#
incref
send<<EOF
senp{to="$siena1" method="PUB" ref=$ref}
event{x=false}
EOF
#
#
incref
send<<EOF
senp{to="$siena2" method="PUB" ref=$ref}
event{x=1.234}
EOF
#
#
incref
send<<EOF
senp{to="$siena0" method="UNS" ref=$ref subscriber="$client/1"}
filter{x *< "ABCDEFuvxyz"}
EOF
#
# @3 1 <-- {x >* "ABCDEFuvxyz"}
#
incref
send<<EOF
senp{to="$siena3" method="SUB" ref=$ref subscriber="$client/1"}
filter{x >* "ABCDEFuvxyz"}
EOF
#
#
incref
send<<EOF
senp{to="$siena0" method="PUB" ref=$ref}
event{x = "ABCDEFuvxyz"}
EOF
expect<<EOF
senp{from="$siena3" method="PUB" ref=$ref to="$client/1" }
event{x="ABCDEFuvxyz"}
EOF
#
#
incref
send<<EOF
senp{to="$siena1" method="PUB" ref=$ref}
event{x = "ABCDEFuvxy"}
EOF
#
#
incref
send<<EOF
senp{to="$siena2" method="PUB" ref=$ref}
event{x = "BCDEFuvxyz"}
EOF
#
#
incref
send<<EOF
senp{to="$siena3" method="PUB" ref=$ref}
event{x="ABCDEFuvxyz123"}
EOF
expect<<EOF
senp{from="$siena3" method="PUB" ref=$ref to="$client/1" }
event{x="ABCDEFuvxyz123"}
EOF
#
#
incref
send<<EOF
senp{to="$siena1" method="PUB" ref=$ref}
event{x="321ABCDEFuvxyz"}
EOF
#
#
incref
send<<EOF
senp{to="$siena0" method="PUB" ref=$ref}
event{x=1234}
EOF
#
#
incref
send<<EOF
senp{to="$siena2" method="PUB" ref=$ref}
event{x=false}
EOF
#
#
incref
send<<EOF
senp{to="$siena3" method="PUB" ref=$ref}
event{x=1.234}
EOF
#
#
incref
send<<EOF
senp{to="$siena3" method="UNS" ref=$ref subscriber="$client/1"}
filter{x >* "ABCDEFuvxyz"}
EOF
#
# @0 1 <-- {x * "DEFuvx"}
#
incref
send<<EOF
senp{to="$siena0" method="SUB" ref=$ref subscriber="$client/1"}
filter{x * "DEFuvx"}
EOF
#
#
incref
send<<EOF
senp{to="$siena2" method="PUB" ref=$ref}
event{x = "ABCDEFuvxyz"}
EOF
expect<<EOF
senp{from="$siena0" method="PUB" ref=$ref to="$client/1" }
event{x="ABCDEFuvxyz"}
EOF
#
incref
send<<EOF
senp{to="$siena1" method="PUB" ref=$ref}
event{x = "ABCDEFuvx"}
EOF
expect<<EOF
senp{from="$siena0" method="PUB" ref=$ref to="$client/1" }
event{x="ABCDEFuvx"}
EOF
#
incref
send<<EOF
senp{to="$siena3" method="PUB" ref=$ref}
event{x = "DEFuvxyz"}
EOF
expect<<EOF
senp{from="$siena0" method="PUB" ref=$ref to="$client/1" }
event{x="DEFuvxyz"}
EOF
#
#
incref
send<<EOF
senp{to="$siena1" method="PUB" ref=$ref}
event{x = "ABCDEFuvvxy"}
EOF
#
#
incref
send<<EOF
senp{to="$siena3" method="PUB" ref=$ref}
event{x = "BCDEFFuvxyz"}
EOF
#
#
incref
send<<EOF
senp{to="$siena0" method="PUB" ref=$ref}
event{x="321ABCDEFuvxyzDEFuvxa"}
EOF
expect<<EOF
senp{from="$siena0" method="PUB" ref=$ref to="$client/1" }
event{x="321ABCDEFuvxyzDEFuvxa"}
EOF
#
incref
send<<EOF
senp{to="$siena1" method="PUB" ref=$ref}
event{x="DEFuvx"}
EOF
expect<<EOF
senp{from="$siena0" method="PUB" ref=$ref to="$client/1" }
event{x="DEFuvx"}
EOF
#
#
incref
send<<EOF
senp{to="$siena2" method="PUB" ref=$ref}
event{x=1234}
EOF
#
#
incref
send<<EOF
senp{to="$siena0" method="PUB" ref=$ref}
event{x=false}
EOF
#
#
incref
send<<EOF
senp{to="$siena0" method="PUB" ref=$ref}
event{x=1.234}
EOF
#
#
incref
send<<EOF
senp{to="$siena0" method="UNS" ref=$ref subscriber="$client/1"}
filter{x * "DEFuvx"}
EOF
#
#
#
# --------------- TEST ENDS HERE -----------------
#
closetest $*
